//
//  Module      : mailqueue.h
//  Author      : Oren Sokoler 
//  E-mail      : orenskl@netvision.net.il
//  Description : Header file for mailqueue.cpp
//
//  Copyright (C) 1999 Oren Sokoler
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

//-----------------------------------------------------
//                   Qt include files
//-----------------------------------------------------

#include <qlistview.h>
#include <qdir.h>

//-----------------------------------------------------
//                   Class MailQueue
//-----------------------------------------------------

class MailQueue : public QWidget {

 protected:

// Method      : resizeEvent
// Description : Resize event for mail queue
// Parameters  : QResizeEvent - Qt resize event
// Returns     : none.
// Notes       : none.
  void resizeEvent ( QResizeEvent * );

// Method      : timerEvent
// Description : timer event from Qt
// Parameters  : QTimerEvent - Qt event
// Returns     : none.
// Notes       : none.
  void timerEvent  ( QTimerEvent  * );

 public:

// Method      : MailQueue
// Description : MailQueue constructor
// Parameters  : QParent  - This widget's parent widget
//               MailQDir - Mail queue directory
//               Time     - Update interval
// Returns     : none.
// Notes       : none.
  MailQueue(QWidget *parent , const char *MailQDir,int Time);

// Method      : ~MailQueue
// Description : MailQueue destructor
// Parameters  : none.
// Returns     : none.
// Notes       : none.
  ~MailQueue(void);

// Method      : setFont
// Description : Sets the font for all the mail queue text
// Parameters  : MailFont - Mail queue font
// Returns     : none.
// Notes       : none.
  void setFont ( const QFont & MailFont );

 private:

  QListView               *List;       // Mail view list
  QString                  MailDir;    // Mail queue directory 
  QList <QListViewItem>    MsgData;    // Mail queue data
};


